@@ -31,7 +31,7 @@
 #include "ctkframelock.h"
 #include "ctkhelp.h"
 
-#include "frame_lock_banner.h"
+#include "ctkimage.h"
 #include "led_green.h"
 #include "led_red.h"
 #include "led_grey.h"
@@ -242,15 +242,11 @@ GtkWidget* ctk_framelock_new(NvCtrlAttributeHandle *handle,
     GtkWidget *hbox;
     GtkWidget *hbox2;
     GtkWidget *label;
-    GtkWidget *frame;
-    GtkWidget *image;
+    GtkWidget *banner;
     GtkWidget *sw;
     GtkWidget *hseparator;
     gint value;
 
-    guint8 *image_buffer = NULL;
-    const nv_image_t *img;
-
     /* make sure we have a handle */
 
     g_return_val_if_fail(handle != NULL, NULL);
@@ -280,25 +276,8 @@ GtkWidget* ctk_framelock_new(NvCtrlAttributeHandle *handle,
 
     /* banner */
 
-    hbox = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(object), hbox, FALSE, FALSE, 0);
-
-    frame = gtk_frame_new(NULL);
-    gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
-    
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-
-    img = &frame_lock_banner_image;
-
-    image_buffer = decompress_image_data(img);
-
-    image = gtk_image_new_from_pixbuf
-        (gdk_pixbuf_new_from_data(image_buffer, GDK_COLORSPACE_RGB,
-                                  FALSE, 8, img->width, img->height,
-                                  img->width * img->bytes_per_pixel,
-                                  free_decompressed_image, NULL));
-
-    gtk_container_add(GTK_CONTAINER(frame), image);
+    banner = ctk_banner_image_new(BANNER_ARTWORK_FRAMELOCK);
+    gtk_box_pack_start(GTK_BOX(ctk_framelock), banner, FALSE, FALSE, 0);
 
     /* scrollable list */
 
@@ -1330,13 +1309,19 @@ static void polarity_toggled(GtkCellRendererToggle *cell,
 
     enabled ^= 1;
 
-    /* don't allow the user to turn off the rising edge */
-    
-    if (mask == NV_CTRL_FRAMELOCK_POLARITY_RISING_EDGE) enabled = TRUE;
-    
     if (enabled) polarity |= mask;
     else         polarity &= ~mask;
     
+
+    /* if the last bit was turned off, turn back on the other bit */
+
+    if (!polarity) {
+        if (mask == NV_CTRL_FRAMELOCK_POLARITY_RISING_EDGE)
+            polarity = NV_CTRL_FRAMELOCK_POLARITY_FALLING_EDGE;
+        if (mask == NV_CTRL_FRAMELOCK_POLARITY_FALLING_EDGE)
+            polarity = NV_CTRL_FRAMELOCK_POLARITY_RISING_EDGE;
+    }
+
     gtk_list_store_set(ctk_framelock->list_store, &iter,
                        COLUMN_POLARITY, polarity, -1);
     
@@ -1348,6 +1333,9 @@ static void polarity_toggled(GtkCellRendererToggle *cell,
     case NV_CTRL_FRAMELOCK_POLARITY_RISING_EDGE:
         polarity_str = "rising";
         break;
+    case NV_CTRL_FRAMELOCK_POLARITY_FALLING_EDGE:
+        polarity_str = "falling";
+        break;
     case NV_CTRL_FRAMELOCK_POLARITY_BOTH_EDGES:
         polarity_str = "rising and falling";
         break;
@@ -2224,12 +2212,9 @@ static GtkWidget *create_error_msg_dialog(CtkFramelock *ctk_framelock)
 
 static void error_msg(CtkFramelock *ctk_framelock, const gchar *fmt, ...)
 {
-    va_list ap;
     gchar *msg;
 
-    va_start(ap, fmt);
-    msg = nv_build_vararg_string(fmt, ap);
-    va_end(ap);
+    NV_VSNPRINTF(msg, fmt);
     
     gtk_label_set_line_wrap(GTK_LABEL(ctk_framelock->error_msg_label), TRUE);
     gtk_label_set_use_markup(GTK_LABEL(ctk_framelock->error_msg_label), TRUE);
